@@ -1,7 +1,7 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 #
 # quakepy/FocalMechanism.py
-# $Id: FocalMechanism.py 208 2009-06-19 14:53:10Z fab $
+# $Id: FocalMechanism.py 792 2010-09-21 12:18:02Z fab $
 #
 # The QuakePy package
 # http://www.quakepy.org
@@ -32,8 +32,8 @@ The QuakePy package
 http://www.quakepy.org
 """
 
-__version__  = '$Id: FocalMechanism.py 208 2009-06-19 14:53:10Z fab $'
-__revision__ = '$Revision: 208 $'
+__version__  = '$Id: FocalMechanism.py 792 2010-09-21 12:18:02Z fab $'
+__revision__ = '$Revision: 792 $'
 __author__   = "Fabian Euchner <fabian@fabian-euchner.de>, Danijel Schorlemmer <ds@usc.edu>"
 __license__  = "GPL"
 
@@ -62,12 +62,12 @@ class FocalMechanism( QPPublicObject ):
     addElements = QPElementList( (
                     QPElement( 'publicID', 'publicID', 'attribute', unicode, 'basic' ),
         
-                    QPElement( 'triggeringOriginID', 'triggeringOriginID', 'element', unicode, 'basic' ),
+                    QPElement( 'triggeringOriginID', 'triggeringOriginID', 'attribute', unicode, 'basic' ),
                     QPElement( 'azimuthalGap', 'azimuthalGap', 'element', float, 'basic' ),
                     QPElement( 'stationPolarityCount', 'stationPolarityCount', 'element', int, 'basic' ),
                     QPElement( 'misfit', 'misfit', 'element', float, 'basic' ),
                     QPElement( 'stationDistributionRatio', 'stationDistributionRatio', 'element', float, 'basic' ),
-                    QPElement( 'methodID', 'methodID', 'element', unicode, 'basic' ),
+                    QPElement( 'methodID', 'methodID', 'attribute', unicode, 'basic' ),
 
                     QPElement( 'nodalPlanes', 'nodalPlanes', 'element', NodalPlanes, 'complex' ),
                     QPElement( 'principalAxes', 'principalAxes', 'element', PrincipalAxes, 'complex' ),
