@@ -1,14 +1,14 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 #
 # quakepy/QPAnnotation.py
-# $Id: QPAnnotation.py 230 2009-09-30 17:56:15Z fab $
+# $Id: QPAnnotation.py 796 2011-02-22 13:09:16Z fab $
 #
 # The QuakePy package
 # http://www.quakepy.org
 #
 
 ############################################################################
-#    Copyright (C) 2007-2009 by Fabian Euchner and Danijel Schorlemmer     #
+#    Copyright (C) 2007-2011 by Fabian Euchner and Danijel Schorlemmer     #
 #    fabian@fabian-euchner.de                                              #
 #                                                                          #
 #    This program is free software; you can redistribute it and#or modify  #
@@ -32,8 +32,8 @@ The QuakePy package
 http://www.quakepy.org
 """
 
-__version__  = '$Id: QPAnnotation.py 230 2009-09-30 17:56:15Z fab $'
-__revision__ = '$Revision: 230 $'
+__version__  = '$Id: QPAnnotation.py 796 2011-02-22 13:09:16Z fab $'
+__revision__ = '$Revision: 796 $'
 __author__   = "Fabian Euchner <fabian@fabian-euchner.de>, Danijel Schorlemmer <ds@usc.edu>"
 __license__  = "GPL"
 
@@ -84,7 +84,7 @@ class QPAnnotation( object ):
         else:
             ostream = output
 
-        if 'prettyPrint' in kwargs.keys() and kwargs['prettyPrint'] is False:
+        if 'prettyPrint' in kwargs and kwargs['prettyPrint'] is False:
             prettyPrint = False
         else:
             prettyPrint = True
@@ -208,7 +208,7 @@ class QPAnnotation( object ):
                                          '</gml:end>',
                                          '</gml:TimePeriod></gml:validTime>' ] )
             
-            #   spatial 
+            # spatial 
             if (      ( self.coverageSpatial['latmin'] is not None ) 
                  and  ( self.coverageSpatial['lonmin'] is not None )
                  and  ( self.coverageSpatial['latmax'] is not None )
@@ -217,10 +217,10 @@ class QPAnnotation( object ):
                 stream.writelines( [ '<gml:boundedBy>',
                                      '<gml:Envelope srsName="urn:EPSG:geographicCRS:4326">',
                                      '<gml:lowerCorner>',
-                                     str( self.coverageSpatial['latmin'] ), ' ', str( self.coverageSpatial['lonmin'] ),
+                                     str( self.coverageSpatial['lonmin'] ), ' ', str( self.coverageSpatial['latmin'] ),
                                      '</gml:lowerCorner>',
                                      '<gml:upperCorner>',
-                                     str( self.coverageSpatial['latmax'] ), ' ', str( self.coverageSpatial['lonmax'] ),
+                                     str( self.coverageSpatial['lonmax'] ), ' ', str( self.coverageSpatial['latmax'] ),
                                      '</gml:upperCorner>',
                                      '</gml:Envelope>',
                                      '</gml:boundedBy>' ] )
@@ -237,18 +237,18 @@ class QPAnnotation( object ):
                 for curr_vertex_idx, curr_vertex in enumerate( self.coverageSpatial['boundary'] ):
 
                     if curr_vertex_idx < len( self.coverageSpatial['boundary'] )-1:
-                        stream.writelines( [ str(curr_vertex[1]), ' ', str(curr_vertex[0]), ' ' ] )
+                        stream.writelines( [ str(curr_vertex[0]), ' ', str(curr_vertex[1]), ' ' ] )
                     else:
                         # last vertex
 
                         # check if polygon is closed
                         if curr_vertex == self.coverageSpatial['boundary'][0]:
-                            stream.writelines( [ str(curr_vertex[1]), ' ', str(curr_vertex[0]) ] )
+                            stream.writelines( [ str(curr_vertex[0]), ' ', str(curr_vertex[1]) ] )
                         else:
                             # polygon is not closed, duplicate first entry
-                            stream.writelines( [ str(curr_vertex[1]), ' ', str(curr_vertex[0]), ' ' ] )
-                            stream.writelines( [ str(self.coverageSpatial['boundary'][0][1]), ' ',
-                                                 str(self.coverageSpatial['boundary'][0][0]) ] )
+                            stream.writelines( [ str(curr_vertex[0]), ' ', str(curr_vertex[1]), ' ' ] )
+                            stream.writelines( [ str(self.coverageSpatial['boundary'][0][0]), ' ',
+                                                 str(self.coverageSpatial['boundary'][0][1]) ] )
                     
                 stream.writelines( [ '</gml:posList>',
                                      '</gml:linearRing>',
@@ -302,69 +302,69 @@ class QPAnnotation( object ):
         """
         
         # title
-        if ( 'title' in kwargs.keys() ) and ( kwargs['title'] is not None ):
+        if ( 'title' in kwargs ) and ( kwargs['title'] is not None ):
             self.title = kwargs['title']
             
         # creator
-        if ( 'creator' in kwargs.keys() ) and ( kwargs['creator'] is not None ):
+        if ( 'creator' in kwargs ) and ( kwargs['creator'] is not None ):
             self.creator = kwargs['creator']
             
         # publisher
-        if ( 'publisher' in kwargs.keys() ) and ( kwargs['publisher'] is not None ):
+        if ( 'publisher' in kwargs ) and ( kwargs['publisher'] is not None ):
             self.publisher = kwargs['publisher']
             
         # rights
-        if ( 'rights' in kwargs.keys() ) and ( kwargs['rights'] is not None ):
+        if ( 'rights' in kwargs ) and ( kwargs['rights'] is not None ):
             self.rights = kwargs['rights']
             
         # subject
-        if ( 'subject' in kwargs.keys() ) and ( kwargs['subject'] is not None ):
+        if ( 'subject' in kwargs ) and ( kwargs['subject'] is not None ):
             self.subject = kwargs['subject']
             
         # source
-        if ( 'source' in kwargs.keys() ) and ( kwargs['source'] is not None ):
+        if ( 'source' in kwargs ) and ( kwargs['source'] is not None ):
             self.source = kwargs['source']
 
         # dcterms:bibliographicCitation
-        if ( 'bibliographicCitation' in kwargs.keys() ) and ( kwargs['bibliographicCitation'] is not None ):
+        if ( 'bibliographicCitation' in kwargs ) and ( kwargs['bibliographicCitation'] is not None ):
             self.bibliographicCitation = kwargs['bibliographicCitation']
             
         # comment
-        if ( 'comment' in kwargs.keys() ) and ( kwargs['comment'] is not None ):
+        if ( 'comment' in kwargs ) and ( kwargs['comment'] is not None ):
             self.comment = kwargs['comment']
 
         # date of program execution / resource publishing date
-        if ( 'date' in kwargs.keys() ) and ( kwargs['date'] is not None ):
+        if ( 'date' in kwargs ) and ( kwargs['date'] is not None ):
             self.date = kwargs['date']
         
         # temporal coverage / point in time for completeness computation
-        if ( 'starttime' in kwargs.keys() ) and ( kwargs['starttime'] is not None ):
+        if ( 'starttime' in kwargs ) and ( kwargs['starttime'] is not None ):
             self.coverageTemporal['starttime'] = kwargs['starttime']
-        if ( 'endtime' in kwargs.keys() ) and ( kwargs['endtime'] is not None ):
+        if ( 'endtime' in kwargs ) and ( kwargs['endtime'] is not None ):
             self.coverageTemporal['endtime'] = kwargs['endtime']
         
         # spatial coverage / grid boundaries
-        if ( 'latmin' in kwargs.keys() ) and ( kwargs['latmin'] is not None ):
+        if ( 'latmin' in kwargs ) and ( kwargs['latmin'] is not None ):
             self.coverageSpatial['latmin'] = kwargs['latmin']
-        if ( 'latmax' in kwargs.keys() ) and ( kwargs['latmax'] is not None ):
+        if ( 'latmax' in kwargs ) and ( kwargs['latmax'] is not None ):
             self.coverageSpatial['latmax'] = kwargs['latmax']
-        if ( 'lonmin' in kwargs.keys() ) and ( kwargs['lonmin'] is not None ):
+        if ( 'lonmin' in kwargs ) and ( kwargs['lonmin'] is not None ):
             self.coverageSpatial['lonmin'] = kwargs['lonmin']
-        if ( 'lonmax' in kwargs.keys() ) and ( kwargs['lonmax'] is not None ):
+        if ( 'lonmax' in kwargs ) and ( kwargs['lonmax'] is not None ):
             self.coverageSpatial['lonmax'] = kwargs['lonmax']
 
-        if ( 'boundary' in kwargs.keys() ) and ( kwargs['boundary'] is not None ):
+        if ( 'boundary' in kwargs ) and ( kwargs['boundary'] is not None ):
             self.coverageSpatial['boundary'] = kwargs['boundary']
             
         # observationTimeInterval
-        if ( 'observationStartTime' in kwargs.keys() ) and ( kwargs['observationStartTime'] is not None ):
+        if ( 'observationStartTime' in kwargs ) and ( kwargs['observationStartTime'] is not None ):
             self.observationTimeInterval['starttime'] = kwargs['observationStartTime']
-        if ( 'observationEndTime' in kwargs.keys() ) and ( kwargs['observationEndTime'] is not None ):
+        if ( 'observationEndTime' in kwargs ) and ( kwargs['observationEndTime'] is not None ):
             self.observationTimeInterval['endtime'] = kwargs['observationEndTime']
 
         # process parameters
         # maxStationCnt
-        if ( 'maxStationCnt' in kwargs.keys() ) and ( kwargs['maxStationCnt'] is not None ):
+        if ( 'maxStationCnt' in kwargs ) and ( kwargs['maxStationCnt'] is not None ):
             self.processParameters['maxStationCnt'] = kwargs['maxStationCnt']
         
         return True
\ No newline at end of file
