@@ -1,7 +1,7 @@
 # -*- coding: iso-8859-1 -*-
 #
 # quakepy/QPCatalogCompact.py
-# $Id: QPCatalogCompact.py 218 2009-07-23 11:38:23Z fab $
+# $Id: QPCatalogCompact.py 1018 2017-02-06 13:13:38Z danijel $
 #
 # The QuakePy package
 # http://www.quakepy.org
@@ -32,8 +32,8 @@ The QuakePy package
 http://www.quakepy.org
 """
 
-__version__  = '$Id: QPCatalogCompact.py 218 2009-07-23 11:38:23Z fab $'
-__revision__ = '$Revision: 218 $'
+__version__  = '$Id: QPCatalogCompact.py 1018 2017-02-06 13:13:38Z danijel $'
+__revision__ = '$Revision: 1018 $'
 __author__   = "Fabian Euchner <fabian@fabian-euchner.de>, Danijel Schorlemmer <ds@usc.edu>"
 __license__  = "GPL"
 
@@ -348,7 +348,11 @@ class QPCatalogCompact( QPObject ):
             curr_ori = curr_ev.getPreferredOrigin()
 
             if 'mag' in columns:
-                curr_mag = curr_ev.getPreferredMagnitude()
+                try:
+                    curr_mag = curr_ev.getPreferredMagnitude()
+                except Exception, e:
+                    print e
+                    raise ValueError
             else:
                 curr_mag = None
                 
@@ -476,9 +480,12 @@ class QPCatalogCompact( QPObject ):
                     try:
                         curr_lon_err = curr_ori.longitude.uncertainty
                         curr_lat_err = curr_ori.latitude.uncertainty
-                        return_value = math.sqrt( math.pow( curr_lat_err * 111.0, 2 ) +
+                        curr_lat = curr_ori.latitude.value
+                        
+                        # math.pi * 6371.0087714 / 180
+                        return_value = math.sqrt( math.pow( curr_lat_err * EARTH_KM_PER_DEGREE, 2 ) +
                                                   math.pow( curr_lon_err * math.cos(curr_lat * math.pi/180.0) *
-                                                            111.0, 2 ) )
+                                                            EARTH_KM_PER_DEGREE, 2 ) )
                         hzErrorFound = True
                     except:
                         pass
