@@ -1,7 +1,7 @@
 # -*- coding: iso-8859-1 -*-
 #
 # quakepy/QPColorMap.py
-# $Id: QPColorMap.py 222 2009-08-28 15:02:41Z fab $
+# $Id: QPColorMap.py 1002 2016-07-01 08:10:57Z danijel $
 #
 # The QuakePy package
 # http://www.quakepy.org
@@ -32,8 +32,8 @@ The QuakePy package
 http://www.quakepy.org
 """
 
-__version__  = '$Id: QPColorMap.py 222 2009-08-28 15:02:41Z fab $'
-__revision__ = '$Revision: 222 $'
+__version__  = '$Id: QPColorMap.py 1002 2016-07-01 08:10:57Z danijel $'
+__revision__ = '$Revision: 1002 $'
 __author__   = "Danijel Schorlemmer <ds@usc.edu>, Fabian Euchner <fabian@fabian-euchner.de>"
 __license__  = "GPL"
 
@@ -135,6 +135,7 @@ class QPColorMap( object ):
     def _convertLine(self, sLine):
 
         vLine = [sLine[2:9], sLine[23:30], sLine[33:40], sLine[43:50]]
+        vLine[0] = float(vLine[0])
         vLine[1] = float(vLine[1])
         vLine[2] = float(vLine[2])
         vLine[3] = float(vLine[3])
@@ -369,7 +370,11 @@ class QPColorMap( object ):
 
         # Write colormap values
         for nCnt in xrange(0, nLen):
-            sLine = str(mColormap[0][nCnt]) + '\t' + str(mColormap[1][nCnt]) + '\t' + str(mColormap[2][nCnt]) + '\t' + str(mColormap[3][nCnt]) + '\t' + str(mColormap[4][nCnt]) + '\t' + str(mColormap[5][nCnt]) + '\t' + str(mColormap[6][nCnt]) + '\t' + str(mColormap[7][nCnt])
+            sLine = str(mColormap[0][nCnt]) + '\t' + str(mColormap[1][nCnt]) \
+                + '\t' + str(mColormap[2][nCnt]) + '\t' + \
+                str(mColormap[3][nCnt]) + '\t' + str(mColormap[4][nCnt]) + \
+                '\t' + str(mColormap[5][nCnt]) + '\t' + \
+                str(mColormap[6][nCnt]) + '\t' + str(mColormap[7][nCnt])
             ftOutput.write(sLine + '\n')
 
         # Write special values
@@ -405,11 +410,11 @@ class QPColorMap( object ):
         return colormap for Matplotlib
         """
 
-        if ('name' in kwargs.keys()) and (kwargs['name'] is not None):
+        if ('name' in kwargs) and (kwargs['name'] is not None):
             sName = kwargs['name']
         else:
             sName = self.sColormapName
-        if ('size' in kwargs.keys()) and (kwargs['size'] is not None):
+        if ('size' in kwargs) and (kwargs['size'] is not None):
             nSize = int(kwargs['size'])
         else:
             nSize = 256
@@ -418,11 +423,13 @@ class QPColorMap( object ):
         blue  = []
         green = []
         for nCnt in xrange(len(self.mData[0])):
-            red.append(  [self.mData[0][nCnt], self.mData[1][nCnt], self.mData[1][nCnt]])
+            red.append([self.mData[0][nCnt], self.mData[1][nCnt], self.mData[1][nCnt]])
             green.append([self.mData[0][nCnt], self.mData[2][nCnt], self.mData[2][nCnt]])
-            blue.append( [self.mData[0][nCnt], self.mData[3][nCnt], self.mData[3][nCnt]])
-        colorDict = {"red":red, "green":green, "blue":blue}
+            blue.append([self.mData[0][nCnt], self.mData[3][nCnt], self.mData[3][nCnt]])
+        
+        colorDict = {"red": red, "green": green, "blue": blue}
         colorMap = matplotlib.colors.LinearSegmentedColormap(sName, colorDict, nSize)
+        
         if (self.vFColor[0] != '-'):
             colorMap.set_over((self.vFColor[0], self.vFColor[1], self.vFColor[2]))
         if (self.vBColor[0] != '-'):
