@@ -1,7 +1,7 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 #
 # quakepy/QPCore.py
-# $Id: QPCore.py 253 2009-11-23 15:35:10Z fab $
+# $Id: QPCore.py 794 2010-09-21 12:33:15Z fab $
 #
 # The QuakePy package
 # http://www.quakepy.org
@@ -32,8 +32,8 @@ The QuakePy package
 http://www.quakepy.org
 """
 
-__version__  = '$Id: QPCore.py 253 2009-11-23 15:35:10Z fab $'
-__revision__ = '$Revision: 253 $'
+__version__  = '$Id: QPCore.py 794 2010-09-21 12:33:15Z fab $'
+__revision__ = '$Revision: 794 $'
 __author__   = "Fabian Euchner <fabian@fabian-euchner.de>, Danijel Schorlemmer <ds@usc.edu>"
 __license__  = "GPL"
 
@@ -556,11 +556,14 @@ class QPPublicObject( QPObject ):
     publicObjectCtr = 0L
 
     # style of publicID
+    # Note: colons are not allowed in smi URIs, so change ':' to '.' in time component
+    # of timestamp
+    #
     #  'full':    'smi:local/generic/2008-07-26T15:00:00'
     #  'short':   'myname' or '2008-07-26T15:00:00'
     #  'numeric': '152763'
-    publicIDStyle = 'full'
 
+    publicIDStyle = 'full'
 
     def __init__( self, publicID = None, **kwargs ):
         super( QPPublicObject, self ).__init__( **kwargs )
@@ -601,7 +604,9 @@ class QPPublicObject( QPObject ):
             if name is not None:
                 id = str( name )
             else:
-                id = mxDateTime2ISO( curr_time, secondsdigits=self.secondsDigits )
+                id = mxDateTime2ISO( curr_time, 
+                                     secondsdigits=self.secondsDigits, 
+                                     timesepreplacechar='.' )
 
         else:
             if not name:
@@ -610,7 +615,9 @@ class QPPublicObject( QPObject ):
             id = ''.join( ( 'smi:local/',
                              name,
                              '/',
-                             mxDateTime2ISO( curr_time, secondsdigits=self.secondsDigits ) ) )
+                             mxDateTime2ISO( curr_time, 
+                                             secondsdigits=self.secondsDigits,
+                                             timesepreplacechar='.' ) ) )
             
         return id
 
