@@ -1,14 +1,14 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 #
 # quakepy/QPUtils.py
-# $Id: QPUtils.py 253 2009-11-23 15:35:10Z fab $
+# $Id: QPUtils.py 956 2014-03-15 14:18:50Z tyrone $
 #
 # The QuakePy package
 # http://www.quakepy.org
 #
 
 ############################################################################
-#    Copyright (C) 2007-2009 by Fabian Euchner and Danijel Schorlemmer     #
+#    Copyright (C) 2007-2013 by Fabian Euchner and Danijel Schorlemmer     #
 #    fabian@fabian-euchner.de                                              #
 #                                                                          #
 #    This program is free software; you can redistribute it and#or modify  #
@@ -32,8 +32,8 @@ The QuakePy package
 http://www.quakepy.org
 """
 
-__version__  = '$Id: QPUtils.py 253 2009-11-23 15:35:10Z fab $'
-__revision__ = '$Revision: 253 $'
+__version__  = '$Id: QPUtils.py 956 2014-03-15 14:18:50Z tyrone $'
+__revision__ = '$Revision: 956 $'
 __author__   = "Fabian Euchner <fabian@fabian-euchner.de>, Danijel Schorlemmer <ds@usc.edu>"
 __license__  = "GPL"
 
@@ -58,6 +58,12 @@ from mx.DateTime.ISO import ParseDateTimeUTC
 
 POS_TAGNAME, POS_ATTRS, POS_CHILDREN = range(3)
 
+
+ARANGE_SAFETY_FACTOR = 1e12
+
+EARTH_RADIUS_KM = 6371.0087714
+EARTH_KM_PER_DEGREE = math.pi * EARTH_RADIUS_KM / 180.0
+
 # -------------------------------------------------------------------------------------
 
 def getQPDataSource( filename, **kwargs ):
@@ -72,7 +78,7 @@ def getQPDataSource( filename, **kwargs ):
         except:
             raise IOError, "getQPDataSource: cannot open data source from URL %s" % filename
 
-        if 'compression' in kwargs.keys():
+        if 'compression' in kwargs:
 
             file_contents = file_object.read()
             
@@ -91,7 +97,7 @@ def getQPDataSource( filename, **kwargs ):
                     raise IOError, "getQPDataSource: cannot open data source from b2zipped stream, URL %s" % filename
 
     else:
-        if 'compression' in kwargs.keys():
+        if 'compression' in kwargs:
 
             if kwargs['compression'] == 'gz':
                 try:
@@ -105,7 +111,7 @@ def getQPDataSource( filename, **kwargs ):
                 except:
                     raise IOError, "getQPDataSource: cannot open b2zipped data source file %s" % filename
         else:
-            if ( 'binary' in kwargs.keys() ) and ( kwargs['binary'] is True ):
+            if ( 'binary' in kwargs ) and ( kwargs['binary'] is True ):
                 open_flag = 'rb'
             else:
                 open_flag = 'r'
@@ -120,7 +126,7 @@ def getQPDataSource( filename, **kwargs ):
 
 def writeQPData( filename, **kwargs ):
 
-    if ( 'compression' in kwargs.keys() ):
+    if ( 'compression' in kwargs ):
 
         if ( kwargs['compression'] == 'gz' ):
             try:
@@ -135,7 +141,7 @@ def writeQPData( filename, **kwargs ):
         else:
             raise IOError, "writeQPData: no valid compression format given"
     else:
-        if ( 'binary' in kwargs.keys() ) and ( kwargs['binary'] is True ):
+        if ( 'binary' in kwargs ) and ( kwargs['binary'] is True ):
             open_flag = 'wb'
         else:
             open_flag = 'w'
@@ -237,7 +243,7 @@ def pyrxpTupleTree2XML( node, stream ):
 # -------------------------------------------------------------------------------------
 
 def pickleObj( obj, file, **kwargs ):
-    fh = writeQPData( file, binary = True, **kwargs )
+    fh = writeQPData( file, binary=True, **kwargs )
     try:
         cPickle.dump( obj, fh, 2 )
     except cPickle.PickleError:
@@ -248,7 +254,7 @@ def pickleObj( obj, file, **kwargs ):
 
 
 def unpickleObj( file, **kwargs ):
-    fh = getQPDataSource( file, binary = True, **kwargs )
+    fh = getQPDataSource( file, binary=True, **kwargs )
     try:
         obj = cPickle.load( fh )
     except cPickle.PickleError:
@@ -313,7 +319,8 @@ class CombinationsNumPy( object ):
     def __init__( self, M, N, **kwargs ):
       
         if ( M <= 1 or N <= 1 or M > N ):
-            raise ValueError, "CombinationsNumPy: illegal M or N"
+            raise ValueError, \
+                "CombinationsNumPy: illegal M or N (%s, %s)" % (M, N)
 
         self.M = M
         self.N = N
@@ -330,24 +337,26 @@ class CombinationsNumPy( object ):
                 self.combinations.append( [] )
                 self.index.append( {} )
 
-        if 'onlyMaxM' in kwargs.keys() and kwargs['onlyMaxM'] is True:
+        if 'onlyMaxM' in kwargs and kwargs['onlyMaxM'] is True:
             # use only one m value: M
             self.mRange = range( self.M, self.M+1, 1)
         else:
             # m range is 2, ..., M
             self.mRange = range( 2, self.M+1, 1)
             
-        if not ( 'nocompute' in kwargs.keys() and kwargs['nocompute'] is True ):
+        if not ( 'nocompute' in kwargs and kwargs['nocompute'] is True ):
             self.compute()
 
 
     def getCombinations( self, m, n ):
         
         if n > self.N or n < 2:
-            raise ValueError, "CombinationsNumPy::getCombinations - illegal n"
+            raise ValueError, \
+                "CombinationsNumPy::getCombinations - illegal n (%s)" % n
         
         if m > n:
-            raise ValueError, "CombinationsNumPy::getCombinations - illegal m, n"
+            raise ValueError, \
+                "CombinationsNumPy::getCombinations - illegal m, n (%s, %s)" % (m, n)
         
         if m > 1 and m <= self.M:
           
@@ -366,7 +375,8 @@ class CombinationsNumPy( object ):
                     yield numpy.concatenate( ( cc, numpy.array( [ curr_n, ] ) ) )
                   
         else:
-            raise ValueError, "CombinationsNumPy::getCombinations - illegal m"
+            raise ValueError, \
+                "CombinationsNumPy::getCombinations - illegal m (%s)" % m
 
 
     def compute( self ):
@@ -440,14 +450,14 @@ class Combinations( object ):
                 self.combinations.append( [] )
                 self.index.append( {} )
         
-        if 'onlyMaxM' in kwargs.keys() and kwargs['onlyMaxM'] is True:
+        if 'onlyMaxM' in kwargs and kwargs['onlyMaxM'] is True:
             # use only one m value: M
             self.mRange = range( self.M, self.M+1, 1)
         else:
             # m range is 2, ..., M
             self.mRange = range( 2, self.M+1, 1)
             
-        if not ( 'nocompute' in kwargs.keys() and kwargs['nocompute'] is True ):
+        if not ( 'nocompute' in kwargs and kwargs['nocompute'] is True ):
             self.compute()
 
 
@@ -554,6 +564,50 @@ def xuniqueCombinations_2(items, n):
 
 # -------------------------------------------------------------------------------------
 
+def convertLatLonDepth2Cartesian(p):
+    """
+    Converts a point given as lat/lon/depth (deg/deg/kilometers) to Cartesian coordinates
+    assuming WGS84. Returns x/y/z in meters
+
+    Source: "Department of Defense World Geodetic System 1984"
+            Page 4-4
+            National Imagery and Mapping Agency
+            Last updated June, 2004
+            NIMA TR8350.2
+    """
+
+    lat = p[0] * math.pi/180.0  # Convert to radians
+    lon = p[1] * math.pi/180.0  # Convert to radians
+    alt = -p[2] * 1000          # Altitude in meters
+
+    # WGS84 ellipsoid constants:
+    a = 6378137.0;
+    b = 8.1819190842622e-2;
+
+    # intermediate calculation
+    # (prime vertical radius of curvature)
+    N = a / math.sqrt(1 - (math.pow(b, 2) * math.pow(math.sin(lat), 2)))
+
+    # results:
+    x = (N + alt) * math.cos(lat) * math.cos(lon);
+    y = (N + alt) * math.cos(lat) * math.sin(lon);
+    z = (((1 - math.pow(b, 2)) * N) + alt) * math.sin(lat);
+
+    return [x, y, z]  # Cartesian coordinates in meters
+
+
+def distanceBetweenPointsWGS84(p1, p2):
+    """
+    Computes the distance between two points given as lat/lon/depth (deg/deg/kilometers)
+    assuming WGS84
+    """
+
+    c1 = convertLatLonDepth2Cartesian(p1)
+    c2 = convertLatLonDepth2Cartesian(p2)
+
+    return math.sqrt(math.pow(c1[0] - c2[0], 2) + math.pow(c1[1] - c2[1], 2) + math.pow(c1[2] - c2[2], 2)) / 1000
+
+
 def distanceBetweenPoints( p1, p2, lat_for_londist = None ):
     """
     computes distance between two geographical points
@@ -582,8 +636,8 @@ def distanceBetweenPoints( p1, p2, lat_for_londist = None ):
     #print p2
     #print use_lat
     
-    distanceXY = math.sqrt( math.pow( (p1_lon - p2_lon) * math.cos(use_lat * math.pi/180.0) * 111.0, 2 ) +
-                       math.pow( (p1_lat - p2_lat) * 111.0, 2 ) )
+    distanceXY = math.sqrt( math.pow( (p1_lon - p2_lon) * math.cos(use_lat * math.pi/180.0) * EARTH_KM_PER_DEGREE, 2 ) +
+                       math.pow( (p1_lat - p2_lat) * EARTH_KM_PER_DEGREE, 2 ) )
     distanceXYZ = math.sqrt( math.pow( distanceXY, 2 ) + math.pow( p1_dep - p2_dep, 2) )
     return ( distanceXYZ, distanceXY )
 
@@ -593,8 +647,8 @@ def horizontalErrorFromLatLon( lat_err, lon_err, latitude ):
     compute horizontal error in km from errors on lat/lon given in degrees
     latitude of point in question is required
     """
-    lat_err_km = lat_err * 111.0
-    lon_err_km = lon_err * math.cos(latitude * math.pi/180.0) * 111.0
+    lat_err_km = lat_err * EARTH_KM_PER_DEGREE
+    lon_err_km = lon_err * math.cos(latitude * math.pi/180.0) * EARTH_KM_PER_DEGREE
     horizontal_error = math.sqrt( math.pow( lat_err_km, 2 ) + math.pow( lon_err_km, 2) )
     return horizontal_error
 
@@ -640,19 +694,19 @@ def mxDateTime2ISO( date_arr, **kwargs ):
         ( date_part, time_part ) = str( date ).split()
          
         # do we show seconds fraction?
-        if ( 'showsecfrac' in kwargs.keys() ) and ( kwargs['showsecfrac'] is False ):
+        if ( 'showsecfrac' in kwargs ) and ( kwargs['showsecfrac'] is False ):
             
             # do not show seconds fraction
             time_part = time_part[:-3]
         else:
           
             # is explicit format string given?
-            if (     'secondsdigits' in kwargs.keys() 
+            if (     'secondsdigits' in kwargs 
                  and isinstance( kwargs['secondsdigits'], int ) 
                  and kwargs['secondsdigits'] > 0 ):
                   
                 # round last decimal place?
-                if ( 'round' in kwargs.keys() ) and ( kwargs['round'] is True ):
+                if ( 'round' in kwargs ) and ( kwargs['round'] is True ):
                   
                     # use format operator for formatting - it rounds automatically
                     # no zero padding at the beginning
@@ -700,16 +754,16 @@ def mxDateTime2ISO( date_arr, **kwargs ):
             time_part = time_part[:-5] + curr_seconds
 
         # replace separator chars
-        if 'datesepreplacechar' in kwargs.keys():
+        if 'datesepreplacechar' in kwargs:
             date_part = re.sub( r'-', kwargs['datesepreplacechar'], date_part )
             
-        if 'timesepreplacechar' in kwargs.keys():
+        if 'timesepreplacechar' in kwargs:
             time_part = re.sub( r':', kwargs['timesepreplacechar'], time_part )
 
-        if 'partsepreplacechar' in kwargs.keys():
+        if 'partsepreplacechar' in kwargs:
             part_separator = kwargs['partsepreplacechar']
             
-        if 'showtime' in kwargs.keys() and kwargs['showtime'] is False:
+        if 'showtime' in kwargs and kwargs['showtime'] is False:
             datetime_str = date_part
         else:
             datetime_str = date_part + part_separator + time_part
@@ -783,32 +837,32 @@ def fixTimeComponents( hour, minute, second ):
     in time strings with the format HH:MM:SS[.ss...], values are sometimes HH=24, MM=60, and SS=60
     meaning the next day, next hour, and next minute
 
-    this function resets the components to allowed values and sets a flag is day, hour, or minute
+    this function resets the components to allowed values and sets a flag if day, hour, or minute
     must be increased
     """
     checked_hour = hour
     checked_min  = minute
     checked_sec  = float( second )
 
-    increaseDay  = False
-    increaseHour = False
-    increaseMin  = False
+    increaseDay  = 0
+    increaseHour = 0
+    increaseMin  = 0
 
-    if hour == 24:
+    if hour >= 24:
         checked_hour = 0
-        increaseDay  = True
-    if minute == 60:
+        increaseDay  = hour/24
+    if minute >= 60:
         checked_min  = 0
-        increaseHour = True
-    if floatEqual( checked_sec, 60.0, 1.0e-9 ):
-        checked_sec = 0.0
-        increaseMin = True
+        increaseHour = minute/60
+    if checked_sec >= 60.0:
+        checked_sec = checked_sec - math.floor(checked_sec) # Preserve fraction of seconds
+        increaseMin = int(checked_sec//60)
          
-    return { 'component'    : ( checked_hour, checked_min, checked_sec ),
-             'increaseFlag' : ( increaseDay, increaseHour, increaseMin ) }
+    return { 'component'     : ( checked_hour, checked_min, checked_sec ),
+             'increaseDelta' : ( increaseDay, increaseHour, increaseMin ) }
 
 
-def adjustDateTime( adjustFlags, dateTime ):
+def adjustDateTime( adjustDelta, dateTime ):
     """
     sometimes a DateTime object has to be adjusted, when illegal components were specified
     adjustDateTime corrects DateTime object with specifications obtained from
@@ -818,20 +872,41 @@ def adjustDateTime( adjustFlags, dateTime ):
     output: corrected DateTime object
     """
 
-    # add one day
-    if adjustFlags[0] is True:
-        dateTime += DateTimeDelta( 1.0 )
+    # Increase day
+    dateTime += DateTimeDelta( adjustDelta[0] )
 
-    # add one hour
-    if adjustFlags[1] is True:
-        dateTime += TimeDelta( 1.0 )
+    # Increase hour
+    dateTime += TimeDelta( adjustDelta[1] )
 
-    # add one minute
-    if adjustFlags[2] is True:
-        dateTime += DateTimeDeltaFromSeconds( 60.0 )
+    # Increase minute
+    dateTime += DateTimeDeltaFromSeconds( 60.0 * adjustDelta[2] )
         
     return dateTime
 
+def correctedDateTimeFromString( year_str, month_str, day_str, hour_str, 
+    minute_str, second_str ):
+    """Return mx.DateTime object from string components. Correct if illegal
+    components are given: hour=24, minute=60, second=60.
+    """
+    
+    correction_applied = False
+    
+    # check if one of the time components has to be corrected
+    timeCorrection = fixTimeComponents( int(hour_str), int(minute_str), 
+        float(second_str) )
+
+    if sum(timeCorrection['increaseDelta']) > 0:
+        correction_applied = True
+        
+    uncorrected_datetime = DateTime( int(year_str), int(month_str), 
+        int(day_str), timeCorrection['component'][0], 
+        timeCorrection['component'][1], timeCorrection['component'][2] )
+                                
+    corrected_datetime = adjustDateTime( timeCorrection['increaseDelta'], 
+        uncorrected_datetime )
+    
+    return (corrected_datetime, correction_applied)
+    
 # -------------------------------------------------------------------------------------
 
 def normalizeFloat( value ):
@@ -860,7 +935,7 @@ def exponentialFloatFromString( mantissa, exponent ):
     >>> 1.283e23 - (10**23 * 1.283)
     16777216.0
 
-    >>> 1.283e23 - float( 'e'.join( ( '+1.281', '23' ) ) )
+    >>> 1.283e23 - float( 'e'.join( ( '+1.283', '23' ) ) )
     0.0
     """
 
@@ -890,6 +965,31 @@ def frange( start, end = None, inc = 1.0 ):
     nitems = int( round( (end - start) / inc ) ) + 1
     return numpy.arange( nitems ) * inc + start
 
+def createFloatRange(xmin, xmax, xstep, center='edge'):
+    """Another version of frange, using integer
+    
+    center: 'edge' put nodes on edges of sub-intervals 
+            'mid' put nodes on centers of  sub-intervals
+            
+    TODO(fab): implement 'edge' method
+    """
+    
+    if center == 'egde':
+        raise NotImplementedError, "method 'edge' not yet implemented"
+    
+    # compute x array in integer to avoid floating point roundoff
+    # errors
+    xmin_scaled = int(ARANGE_SAFETY_FACTOR * (xmin + 0.5 * xstep))
+    xmax_scaled = int(ARANGE_SAFETY_FACTOR * (xmax - 0.5 * xstep))
+    xstep_scaled = int(ARANGE_SAFETY_FACTOR * xstep)
+    
+    xsize_scaled = (xmax_scaled - xmin_scaled + xstep_scaled) / \
+        xstep_scaled
+
+    x_arr = numpy.linspace(xmin_scaled, xmax_scaled, num=xsize_scaled) / \
+        ARANGE_SAFETY_FACTOR
+    
+    return x_arr
 
 def remove_ij( x, i=None, j=None ):
     """
@@ -944,6 +1044,8 @@ def locateInArray( array, value ):
                         idx=len(array)-1:   value is larger than upper array bound
 
     built after Numerical Recipes 'locate' routine
+    
+    NOTE(fab): obsolete, use numpy.searchsorted()
     """
 
     n          = len( array )
@@ -1065,10 +1167,14 @@ def memory(since=0.0):
     ''' Return virtual memory usage in bytes. '''
     return _VmB('VmSize:') - since
 
+def peakmem(since=0.0):
+    ''' Return peak memory usage in bytes. '''
+    return _VmB('VmPeak:') - since
+
 def resident(since=0.0):
     ''' Return resident memory usage in bytes. '''
     return _VmB('VmRSS:') - since
 
 def stacksize(since=0.0):
     ''' Return stack size in bytes. '''
-    return _VmB('VmStk:') - since
\ No newline at end of file
+    return _VmB('VmStk:') - since
