@@ -1,7 +1,7 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 #
 # quakepy/qpseismicityplot.py
-# $Id: qpseismicityplot.py 156 2009-02-13 12:16:25Z fab $
+# $Id: qpseismicityplot.py 923 2014-02-21 16:22:26Z tyrone $
 #
 # The QuakePy package
 # http://www.quakepy.org
@@ -32,15 +32,14 @@ The QuakePy package
 http://www.quakepy.org
 """
 
-__version__  = '$Id: qpseismicityplot.py 156 2009-02-13 12:16:25Z fab $'
-__revision__ = '$Revision: 156 $'
+__version__  = '$Id: qpseismicityplot.py 923 2014-02-21 16:22:26Z tyrone $'
+__revision__ = '$Revision: 923 $'
 __author__   = "Fabian Euchner <fabian@fabian-euchner.de>, Danijel Schorlemmer <ds@usc.edu>"
 __license__  = "GPL"
 
 import os
 import datetime
 import matplotlib
-matplotlib.use('PS')
 
 from pylab import *
 from matplotlib import rcParams
@@ -191,25 +190,25 @@ class QPSeismicityPlot( qpplot.QPPlot ):
                 pass
             
         # check if lat/lon range is given in kwargs
-        if 'gmt_latmin' in kwargs.keys():
+        if 'gmt_latmin' in kwargs:
             latmin = kwargs['gmt_latmin']
         else:
             latmin = min(lat)
             latmin = ( latmin < 0.0 and [1.05*latmin] or [0.95*latmin] )[0]
             
-        if 'gmt_latmax' in kwargs.keys():
+        if 'gmt_latmax' in kwargs:
             latmax = kwargs['gmt_latmax']
         else:
             latmax = max(lat)
             latmax = ( latmax < 0.0 and [0.95*latmax] or [1.05*latmax] )[0]
             
-        if 'gmt_lonmin' in kwargs.keys():
+        if 'gmt_lonmin' in kwargs:
             lonmin = kwargs['gmt_lonmin']
         else:
             lonmin = min(lon)
             lonmin = ( lonmin < 0.0 and [1.05*lonmin] or [0.95*lonmin] )[0]
             
-        if 'gmt_lonmax' in kwargs.keys():
+        if 'gmt_lonmax' in kwargs:
             lonmax = kwargs['gmt_lonmax']
         else:
             lonmax = max(lon)
@@ -228,31 +227,31 @@ class QPSeismicityPlot( qpplot.QPPlot ):
         #   'ortho'     - Orthographic
         #   'gst'       - general stereographic.
  
-        proj      = ( 'gmt_proj' in kwargs.keys() and [kwargs['gmt_proj']] or [self.gmt_proj] )[0]
-        xsize     = ( 'gmt_xsize' in kwargs.keys() and [kwargs['gmt_xsize']] or [self.gmt_xsize] )[0]
-        ysize     = ( 'gmt_ysize' in kwargs.keys() and [kwargs['gmt_ysize']] or [self.gmt_ysize] )[0]
-        xyunits   = ( 'gmt_xyunits' in kwargs.keys() and [kwargs['gmt_xyunits']] or [self.gmt_xyunits] )[0]
-        xshift    = ( 'gmt_xshift' in kwargs.keys() and [kwargs['gmt_xshift']] or [self.gmt_xshift] )[0]
-        yshift    = ( 'gmt_yshift' in kwargs.keys() and [kwargs['gmt_yshift']] or [self.gmt_yshift] )[0]
-        centerlon = ( 'gmt_centerlon' in kwargs.keys() and [kwargs['gmt_centerlon']] or [self.gmt_centerlon] )[0]
-        centerlat = ( 'gmt_centerlat' in kwargs.keys() and [kwargs['gmt_centerlat']] or [self.gmt_centerlat] )[0]
+        proj      = ( 'gmt_proj' in kwargs and [kwargs['gmt_proj']] or [self.gmt_proj] )[0]
+        xsize     = ( 'gmt_xsize' in kwargs and [kwargs['gmt_xsize']] or [self.gmt_xsize] )[0]
+        ysize     = ( 'gmt_ysize' in kwargs and [kwargs['gmt_ysize']] or [self.gmt_ysize] )[0]
+        xyunits   = ( 'gmt_xyunits' in kwargs and [kwargs['gmt_xyunits']] or [self.gmt_xyunits] )[0]
+        xshift    = ( 'gmt_xshift' in kwargs and [kwargs['gmt_xshift']] or [self.gmt_xshift] )[0]
+        yshift    = ( 'gmt_yshift' in kwargs and [kwargs['gmt_yshift']] or [self.gmt_yshift] )[0]
+        centerlon = ( 'gmt_centerlon' in kwargs and [kwargs['gmt_centerlon']] or [self.gmt_centerlon] )[0]
+        centerlat = ( 'gmt_centerlat' in kwargs and [kwargs['gmt_centerlat']] or [self.gmt_centerlat] )[0]
         
         # lat/lon grid lines, tick minor/major tick marks, labels
-        latgrdinc = ( 'gmt_latgrdinc' in kwargs.keys() and [kwargs['gmt_latgrdinc']] or [self.gmt_latgrdinc] )[0]
-        longrdinc = ( 'gmt_longrdinc' in kwargs.keys() and [kwargs['gmt_longrdinc']] or [self.gmt_longrdinc] )[0]
+        latgrdinc = ( 'gmt_latgrdinc' in kwargs and [kwargs['gmt_latgrdinc']] or [self.gmt_latgrdinc] )[0]
+        longrdinc = ( 'gmt_longrdinc' in kwargs and [kwargs['gmt_longrdinc']] or [self.gmt_longrdinc] )[0]
         
-        basemaptype         = ( 'gmt_basemaptype' in kwargs.keys() and [kwargs['gmt_basemaptype']] or [self.gmt_basemaptype] )[0]
-        headerfontsize      = ( 'gmt_headerfontsize' in kwargs.keys() and [kwargs['gmt_headerfontsize']] or [self.gmt_headerfontsize] )[0]
-        labelfontsize       = ( 'gmt_labelfontsize' in kwargs.keys() and [kwargs['gmt_labelfontsize']] or [self.gmt_labelfontsize] )[0]
-        axisfontsize        = ( 'gmt_axisfontsize' in kwargs.keys() and [kwargs['gmt_axisfontsize']] or [self.gmt_axisfontsize] )[0]
+        basemaptype         = ( 'gmt_basemaptype' in kwargs and [kwargs['gmt_basemaptype']] or [self.gmt_basemaptype] )[0]
+        headerfontsize      = ( 'gmt_headerfontsize' in kwargs and [kwargs['gmt_headerfontsize']] or [self.gmt_headerfontsize] )[0]
+        labelfontsize       = ( 'gmt_labelfontsize' in kwargs and [kwargs['gmt_labelfontsize']] or [self.gmt_labelfontsize] )[0]
+        axisfontsize        = ( 'gmt_axisfontsize' in kwargs and [kwargs['gmt_axisfontsize']] or [self.gmt_axisfontsize] )[0]
         
-        maintitle           = ( 'gmt_maintitle' in kwargs.keys() and [kwargs['gmt_maintitle']] or [self.gmt_maintitle] )[0]
-        lefttitle           = ( 'gmt_lefttitle' in kwargs.keys() and [kwargs['gmt_lefttitle']] or [self.gmt_lefttitle] )[0]
-        righttitle          = ( 'gmt_righttitle' in kwargs.keys() and [kwargs['gmt_righttitle']] or [self.gmt_righttitle] )[0]
+        maintitle           = ( 'gmt_maintitle' in kwargs and [kwargs['gmt_maintitle']] or [self.gmt_maintitle] )[0]
+        lefttitle           = ( 'gmt_lefttitle' in kwargs and [kwargs['gmt_lefttitle']] or [self.gmt_lefttitle] )[0]
+        righttitle          = ( 'gmt_righttitle' in kwargs and [kwargs['gmt_righttitle']] or [self.gmt_righttitle] )[0]
         
         # map scale: mapscale mapscalestyle mapscalelatlon mapscalelength mapscalexpos mapscaleypos
-        mapscale            = ( 'gmt_mapscale' in kwargs.keys() and [kwargs['gmt_mapscale']] or [self.gmt_mapscale] )[0]
-        mapscalestyle       = ( 'gmt_mapscalestyle' in kwargs.keys() and [kwargs['gmt_mapscalestyle']] or [self.gmt_mapscalestyle] )[0]
+        mapscale            = ( 'gmt_mapscale' in kwargs and [kwargs['gmt_mapscale']] or [self.gmt_mapscale] )[0]
+        mapscalestyle       = ( 'gmt_mapscalestyle' in kwargs and [kwargs['gmt_mapscalestyle']] or [self.gmt_mapscalestyle] )[0]
     
         ## TODO
         #mapscalelatlon
@@ -267,26 +266,26 @@ class QPSeismicityPlot( qpplot.QPPlot ):
         #mapscaleypos
         #ysize/10 | y-position of map scale.
         
-        eaxis               = ( 'gmt_eaxis' in kwargs.keys() and [kwargs['gmt_eaxis']] or [self.gmt_eaxis] )[0]
-        elabels             = ( 'gmt_elabels' in kwargs.keys() and [kwargs['gmt_elabels']] or [self.gmt_elabels] )[0]
-        naxis               = ( 'gmt_naxis' in kwargs.keys() and [kwargs['gmt_naxis']] or [self.gmt_naxis] )[0]
-        nlabels             = ( 'gmt_nlabels' in kwargs.keys() and [kwargs['gmt_nlabels']] or [self.gmt_nlabels] )[0]
-        saxis               = ( 'gmt_saxis' in kwargs.keys() and [kwargs['gmt_saxis']] or [self.gmt_saxis] )[0]
-        slabels             = ( 'gmt_slabels' in kwargs.keys() and [kwargs['gmt_slabels']] or [self.gmt_slabels] )[0]
-        waxis               = ( 'gmt_waxis' in kwargs.keys() and [kwargs['gmt_waxis']] or [self.gmt_waxis] )[0]
-        wlabels             = ( 'gmt_wlabels' in kwargs.keys() and [kwargs['gmt_wlabels']] or [self.gmt_wlabels] )[0]
+        eaxis               = ( 'gmt_eaxis' in kwargs and [kwargs['gmt_eaxis']] or [self.gmt_eaxis] )[0]
+        elabels             = ( 'gmt_elabels' in kwargs and [kwargs['gmt_elabels']] or [self.gmt_elabels] )[0]
+        naxis               = ( 'gmt_naxis' in kwargs and [kwargs['gmt_naxis']] or [self.gmt_naxis] )[0]
+        nlabels             = ( 'gmt_nlabels' in kwargs and [kwargs['gmt_nlabels']] or [self.gmt_nlabels] )[0]
+        saxis               = ( 'gmt_saxis' in kwargs and [kwargs['gmt_saxis']] or [self.gmt_saxis] )[0]
+        slabels             = ( 'gmt_slabels' in kwargs and [kwargs['gmt_slabels']] or [self.gmt_slabels] )[0]
+        waxis               = ( 'gmt_waxis' in kwargs and [kwargs['gmt_waxis']] or [self.gmt_waxis] )[0]
+        wlabels             = ( 'gmt_wlabels' in kwargs and [kwargs['gmt_wlabels']] or [self.gmt_wlabels] )[0]
         
-        coastlines          = ( 'gmt_coastlines' in kwargs.keys() and [kwargs['gmt_coastlines']] or [self.gmt_coastlines] )[0]
-        coastres            = ( 'gmt_coastres' in kwargs.keys() and [kwargs['gmt_coastres']] or [self.gmt_coastres] )[0]
-        coastthick          = ( 'gmt_coastthick' in kwargs.keys() and [kwargs['gmt_coastthick']] or [self.gmt_coastthick] )[0]
-        countries           = ( 'gmt_countries' in kwargs.keys() and [kwargs['gmt_countries']] or [self.gmt_countries] )[0]
-        countrythick        = ( 'gmt_countrythick' in kwargs.keys() and [kwargs['gmt_countrythick']] or [self.gmt_countrythick] )[0]
+        coastlines          = ( 'gmt_coastlines' in kwargs and [kwargs['gmt_coastlines']] or [self.gmt_coastlines] )[0]
+        coastres            = ( 'gmt_coastres' in kwargs and [kwargs['gmt_coastres']] or [self.gmt_coastres] )[0]
+        coastthick          = ( 'gmt_coastthick' in kwargs and [kwargs['gmt_coastthick']] or [self.gmt_coastthick] )[0]
+        countries           = ( 'gmt_countries' in kwargs and [kwargs['gmt_countries']] or [self.gmt_countries] )[0]
+        countrythick        = ( 'gmt_countrythick' in kwargs and [kwargs['gmt_countrythick']] or [self.gmt_countrythick] )[0]
         
-        continents          = ( 'gmt_continents' in kwargs.keys() and [kwargs['gmt_continents']] or [self.gmt_continents] )[0]
-        continentfill       = ( 'gmt_continentfill' in kwargs.keys() and [kwargs['gmt_continentfill']] or [self.gmt_continentfill] )[0]
-        continentfillcolor  = ( 'gmt_continentfillcolor' in kwargs.keys() and [kwargs['gmt_continentfillcolor']] or [self.gmt_continentfillcolor] )[0]
-        oceanfill           = ( 'gmt_oceanfill' in kwargs.keys() and [kwargs['gmt_oceanfill']] or [self.gmt_oceanfill] )[0]
-        oceanfillcolor      = ( 'gmt_oceanfillcolor' in kwargs.keys() and [kwargs['gmt_oceanfillcolor']] or [self.gmt_oceanfillcolor] )[0]
+        continents          = ( 'gmt_continents' in kwargs and [kwargs['gmt_continents']] or [self.gmt_continents] )[0]
+        continentfill       = ( 'gmt_continentfill' in kwargs and [kwargs['gmt_continentfill']] or [self.gmt_continentfill] )[0]
+        continentfillcolor  = ( 'gmt_continentfillcolor' in kwargs and [kwargs['gmt_continentfillcolor']] or [self.gmt_continentfillcolor] )[0]
+        oceanfill           = ( 'gmt_oceanfill' in kwargs and [kwargs['gmt_oceanfill']] or [self.gmt_oceanfill] )[0]
+        oceanfillcolor      = ( 'gmt_oceanfillcolor' in kwargs and [kwargs['gmt_oceanfillcolor']] or [self.gmt_oceanfillcolor] )[0]
         
         plot = gmt.GMT( latmin=latmin, latmax=latmax, lonmin=lonmin, lonmax=lonmax, proj=proj, 
                         xsize=xsize, ysize=ysize, xyunits=xyunits, xshift=xshift, yshift=yshift, 
@@ -339,9 +338,9 @@ class QPSeismicityPlot( qpplot.QPPlot ):
         plot.mapscalestyle = mapscalestyle
            
         # plot symbols for events
-        event_symbol_type  = ( 'gmt_event_symbol_type' in kwargs.keys() and [kwargs['gmt_event_symbol_type']] or [self.gmt_event_symbol_type] )[0]
-        event_symbol_size  = ( 'gmt_event_symbol_size' in kwargs.keys() and [kwargs['gmt_event_symbol_size']] or [self.gmt_event_symbol_size] )[0]
-        event_symbol_color = ( 'gmt_event_symbol_color' in kwargs.keys() and [kwargs['gmt_event_symbol_color']] or [self.gmt_event_symbol_color] )[0]
+        event_symbol_type  = ( 'gmt_event_symbol_type' in kwargs and [kwargs['gmt_event_symbol_type']] or [self.gmt_event_symbol_type] )[0]
+        event_symbol_size  = ( 'gmt_event_symbol_size' in kwargs and [kwargs['gmt_event_symbol_size']] or [self.gmt_event_symbol_size] )[0]
+        event_symbol_color = ( 'gmt_event_symbol_color' in kwargs and [kwargs['gmt_event_symbol_color']] or [self.gmt_event_symbol_color] )[0]
 
         plot.basemap()
         plot.drawsymbol( lat, lon, symbol=event_symbol_type, size=event_symbol_size, color=event_symbol_color )
@@ -353,8 +352,8 @@ class QPSeismicityPlot( qpplot.QPPlot ):
         plot x-axis 'longitude', y-axis 'latitude'
         """
         
-        event_symbol_type  = ( 'mpl_event_symbol_type' in kwargs.keys() and [kwargs['mpl_event_symbol_type']] or [self.mpl_event_symbol_type] )[0]
-        line_style         = ( 'mpl_line_style' in kwargs.keys() and [kwargs['mpl_line_style']] or [self.mpl_line_style] )[0]
+        event_symbol_type  = ( 'mpl_event_symbol_type' in kwargs and [kwargs['mpl_event_symbol_type']] or [self.mpl_event_symbol_type] )[0]
+        line_style         = ( 'mpl_line_style' in kwargs and [kwargs['mpl_line_style']] or [self.mpl_line_style] )[0]
 
         coastfile  = 'coast.tmp'
         
@@ -372,7 +371,7 @@ class QPSeismicityPlot( qpplot.QPPlot ):
         ax = subplot(111)
         plot( lon, lat, event_symbol_type )
             
-        if 'mpl_coastlines' in kwargs.keys() and kwargs['mpl_coastlines'] == True:
+        if 'mpl_coastlines' in kwargs and kwargs['mpl_coastlines'] == True:
            xmin, xmax = xlim()
            ymin, ymax = ylim()
            
